@@ -4,16 +4,16 @@
 
 import Url from '../../url/index';
 import xdrClient from '../client/xdr';
-import { inBrowser } from '../../util';
+import {inBrowser} from '../../util';
 
 const SUPPORTS_CORS = inBrowser && 'withCredentials' in new XMLHttpRequest();
 
-export default function (request, next) {
+export default function (request) {
 
     if (inBrowser) {
 
-        var orgUrl = Url.parse(location.href);
-        var reqUrl = Url.parse(request.getUrl());
+        const orgUrl = Url.parse(location.href);
+        const reqUrl = Url.parse(request.getUrl());
 
         if (reqUrl.protocol !== orgUrl.protocol || reqUrl.host !== orgUrl.host) {
 
@@ -26,5 +26,4 @@ export default function (request, next) {
         }
     }
 
-    next();
 }
