@@ -2,22 +2,21 @@
  * JSON Interceptor.
  */
 
-import Url from '../../url/index';
-import { when, isObject } from '../../util';
+import {when, isObject} from '../../util';
 
-export default function (request, next) {
+export default function (request) {
 
-    var type = request.headers.get('Content-Type') || '';
+    const type = request.headers.get('Content-Type') || '';
 
     if (isObject(request.body) && type.indexOf('application/json') === 0) {
         request.body = JSON.stringify(request.body);
     }
 
-    next(response => {
+    return response => {
 
         return response.bodyText ? when(response.text(), text => {
 
-            type = response.headers.get('Content-Type') || '';
+            const type = response.headers.get('Content-Type') || '';
 
             if (type.indexOf('application/json') === 0 || isJson(text)) {
 
@@ -35,12 +34,13 @@ export default function (request, next) {
 
         }) : response;
 
-    });
+    };
 }
 
 function isJson(str) {
 
-    var start = str.match(/^\[|^\{(?!\{)/), end = {'[': /]$/, '{': /}$/};
+    const start = str.match(/^\s*(\[|\{)/);
+    const end = {'[': /]\s*$/, '{': /}\s*$/};
 
-    return start && end[start[0]].test(str);
+    return start && end[start[1]].test(str);
 }
