@@ -9,8 +9,10 @@ module.exports = config => {
     browsers: ['Chrome', 'Safari', 'Firefox'],
 
     files: [
-      'index.js',
-      {pattern: 'data/*', included: false},
+      'index.js', {
+        pattern: 'data/*',
+        included: false
+      },
     ],
 
     preprocessors: {
@@ -21,6 +23,10 @@ module.exports = config => {
       '/data/': '/base/data/'
     },
 
+    webpack: {
+      mode: 'development'
+    },
+
   });
 
 };
